Module blaxel.core.client.models.logs_response_data
===================================================

Classes
-------

`LogsResponseData(body: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, log_attributes: blaxel.core.client.types.Unset | list[typing.Any] = <blaxel.core.client.types.Unset object>, severity_number: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, timestamp: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, trace_id: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Response data for logs
    
    Attributes:
        body (Union[Unset, str]): Body of the log
        log_attributes (Union[Unset, list[Any]]): Log attributes
        severity_number (Union[Unset, int]): Severity number of the log
        timestamp (Union[Unset, str]): Timestamp of the log
        trace_id (Union[Unset, str]): Trace ID of the log
    
    Method generated by attrs for class LogsResponseData.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `body: blaxel.core.client.types.Unset | str`
    :

    `log_attributes: blaxel.core.client.types.Unset | list[typing.Any]`
    :

    `severity_number: blaxel.core.client.types.Unset | int`
    :

    `timestamp: blaxel.core.client.types.Unset | str`
    :

    `trace_id: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :